# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/compute_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import destinations_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_destinations__pb2
from kaskada.kaskada.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.kaskada.v1alpha import plan_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_plan__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-kaskada/kaskada/v1alpha/compute_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a$kaskada/kaskada/v1alpha/common.proto\x1a*kaskada/kaskada/v1alpha/destinations.proto\x1a.kaskada/kaskada/v1alpha/fenl_diagnostics.proto\x1a\"kaskada/kaskada/v1alpha/plan.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\"`\n\nFeatureSet\x12<\n\x08\x66ormulas\x18\x01 \x03(\x0b\x32 .kaskada.kaskada.v1alpha.FormulaR\x08\x66ormulas\x12\x14\n\x05query\x18\x02 \x01(\tR\x05query\"`\n\x07\x46ormula\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07\x66ormula\x18\x02 \x01(\tR\x07\x66ormula\x12\'\n\x0fsource_location\x18\x03 \x01(\tR\x0esourceLocation\"\xf9\x02\n\x0c\x43omputeTable\x12<\n\x06\x63onfig\x18\x01 \x01(\x0b\x32$.kaskada.kaskada.v1alpha.TableConfigR\x06\x63onfig\x12\x42\n\x08metadata\x18\x02 \x01(\x0b\x32&.kaskada.kaskada.v1alpha.TableMetadataR\x08metadata\x12J\n\tfile_sets\x18\x03 \x03(\x0b\x32-.kaskada.kaskada.v1alpha.ComputeTable.FileSetR\x08\x66ileSets\x1a\x9a\x01\n\x07\x46ileSet\x12\x41\n\nslice_plan\x18\x01 \x01(\x0b\x32\".kaskada.kaskada.v1alpha.SlicePlanR\tslicePlan\x12L\n\x0eprepared_files\x18\x02 \x03(\x0b\x32%.kaskada.kaskada.v1alpha.PreparedFileR\rpreparedFiles\"\x1e\n\x08PlanHash\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\"#\n\x0bResultPaths\x12\x14\n\x05paths\x18\x01 \x03(\tR\x05paths\"\"\n GetCurrentSnapshotVersionRequest\"N\n!GetCurrentSnapshotVersionResponse\x12)\n\x10snapshot_version\x18\x01 \x01(\x05R\x0fsnapshotVersion\"\xb0\x04\n\x0e\x43ompileRequest\x12=\n\x06tables\x18\x01 \x03(\x0b\x32%.kaskada.kaskada.v1alpha.ComputeTableR\x06tables\x12\x44\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32#.kaskada.kaskada.v1alpha.FeatureSetR\nfeatureSet\x12J\n\rslice_request\x18\x03 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.SliceRequestR\x0csliceRequest\x12_\n\x0f\x65xpression_kind\x18\x04 \x01(\x0e\x32\x36.kaskada.kaskada.v1alpha.CompileRequest.ExpressionKindR\x0e\x65xpressionKind\x12\"\n\x0c\x65xperimental\x18\x05 \x01(\x08R\x0c\x65xperimental\x12Z\n\x13per_entity_behavior\x18\x06 \x01(\x0e\x32*.kaskada.kaskada.v1alpha.PerEntityBehaviorR\x11perEntityBehavior\"l\n\x0e\x45xpressionKind\x12\x1f\n\x1b\x45XPRESSION_KIND_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45XPRESSION_KIND_COMPLETE\x10\x01\x12\x1b\n\x17\x45XPRESSION_KIND_FORMULA\x10\x02\"\xe0\x03\n\x0f\x43ompileResponse\x12#\n\rmissing_names\x18\x01 \x03(\tR\x0cmissingNames\x12S\n\x10\x66\x65nl_diagnostics\x18\x02 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12\x38\n\x04plan\x18\x03 \x01(\x0b\x32$.kaskada.kaskada.v1alpha.ComputePlanR\x04plan\x12\x42\n\x0bresult_type\x18\x04 \x01(\x0b\x32!.kaskada.kaskada.v1alpha.DataTypeR\nresultType\x12\x1d\n\nfree_names\x18\x05 \x03(\tR\tfreeNames\x12\x45\n\x0ctable_slices\x18\x06 \x03(\x0b\x32\".kaskada.kaskada.v1alpha.SlicePlanR\x0btableSlices\x12/\n\x13incremental_enabled\x18\x07 \x01(\x08R\x12incrementalEnabled\x12>\n\tplan_hash\x18\x08 \x01(\x0b\x32!.kaskada.kaskada.v1alpha.PlanHashR\x08planHash\"\x85\x07\n\x0e\x45xecuteRequest\x12\x38\n\x04plan\x18\x01 \x01(\x0b\x32$.kaskada.kaskada.v1alpha.ComputePlanR\x04plan\x12=\n\x06tables\x18\x02 \x03(\x0b\x32%.kaskada.kaskada.v1alpha.ComputeTableR\x06tables\x12M\n\toutput_to\x18\x03 \x01(\x0b\x32\x30.kaskada.kaskada.v1alpha.ExecuteRequest.OutputToR\x08outputTo\x12\x46\n\x06limits\x18\x05 \x01(\x0b\x32..kaskada.kaskada.v1alpha.ExecuteRequest.LimitsR\x06limits\x12u\n\x17\x63ompute_snapshot_config\x18\x06 \x01(\x0b\x32=.kaskada.kaskada.v1alpha.ExecuteRequest.ComputeSnapshotConfigR\x15\x63omputeSnapshotConfig\x12?\n\rchanged_since\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x63hangedSince\x12\x46\n\x11\x66inal_result_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inalResultTime\x1a+\n\x06Limits\x12!\n\x0cpreview_rows\x18\x01 \x01(\x03R\x0bpreviewRows\x1a{\n\x15\x43omputeSnapshotConfig\x12#\n\routput_prefix\x18\x01 \x01(\tR\x0coutputPrefix\x12=\n\x0bresume_from\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nresumeFrom\x1a\xb2\x01\n\x08OutputTo\x12T\n\x0cobject_store\x18\x01 \x01(\x0b\x32/.kaskada.kaskada.v1alpha.ObjectStoreDestinationH\x00R\x0bobjectStore\x12\x41\n\x05redis\x18\x02 \x01(\x0b\x32).kaskada.kaskada.v1alpha.RedisDestinationH\x00R\x05redisB\r\n\x0b\x64\x65stinationJ\x04\x08\t\x10\n\"\xd3\x08\n\x0f\x45xecuteResponse\x12=\n\x05state\x18\x01 \x01(\x0e\x32\'.kaskada.kaskada.v1alpha.LongQueryStateR\x05state\x12\"\n\ris_query_done\x18\x02 \x01(\x08R\x0bisQueryDone\x12X\n\x08progress\x18\x03 \x01(\x0b\x32<.kaskada.kaskada.v1alpha.ExecuteResponse.ProgressInformationR\x08progress\x12G\n\x0coutput_paths\x18\x04 \x01(\x0b\x32$.kaskada.kaskada.v1alpha.ResultPathsR\x0boutputPaths\x12J\n\x12\x66light_record_path\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x10\x66lightRecordPath\x12\x42\n\x0eplan_yaml_path\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cplanYamlPath\x12\x65\n\x11\x63ompute_snapshots\x18\x07 \x03(\x0b\x32\x38.kaskada.kaskada.v1alpha.ExecuteResponse.ComputeSnapshotR\x10\x63omputeSnapshots\x1a\xed\x02\n\x13ProgressInformation\x12(\n\x10total_input_rows\x18\x01 \x01(\x03R\x0etotalInputRows\x12\x30\n\x14processed_input_rows\x18\x02 \x01(\x03R\x12processedInputRows\x12#\n\rbuffered_rows\x18\x03 \x01(\x03R\x0c\x62ufferedRows\x12\x36\n\x17processed_buffered_rows\x18\x08 \x01(\x03R\x15processedBufferedRows\x12$\n\x0emin_event_time\x18\x04 \x01(\x03R\x0cminEventTime\x12$\n\x0emax_event_time\x18\x05 \x01(\x03R\x0cmaxEventTime\x12\x1f\n\x0boutput_time\x18\x06 \x01(\x03R\noutputTime\x12\x30\n\x14produced_output_rows\x18\x07 \x01(\x03R\x12producedOutputRows\x1a\xd2\x01\n\x0f\x43omputeSnapshot\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12@\n\x0emax_event_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cmaxEventTime\x12>\n\tplan_hash\x18\x03 \x01(\x0b\x32!.kaskada.kaskada.v1alpha.PlanHashR\x08planHash\x12)\n\x10snapshot_version\x18\x04 \x01(\x05R\x0fsnapshotVersion*\x8a\x01\n\x0eLongQueryState\x12 \n\x1cLONG_QUERY_STATE_UNSPECIFIED\x10\x00\x12\x1c\n\x18LONG_QUERY_STATE_INITIAL\x10\x01\x12\x1c\n\x18LONG_QUERY_STATE_RUNNING\x10\x02\x12\x1a\n\x16LONG_QUERY_STATE_FINAL\x10\x03\x32\xe3\x02\n\x0e\x43omputeService\x12\\\n\x07\x43ompile\x12\'.kaskada.kaskada.v1alpha.CompileRequest\x1a(.kaskada.kaskada.v1alpha.CompileResponse\x12^\n\x07\x45xecute\x12\'.kaskada.kaskada.v1alpha.ExecuteRequest\x1a(.kaskada.kaskada.v1alpha.ExecuteResponse0\x01\x12\x92\x01\n\x19GetCurrentSnapshotVersion\x12\x39.kaskada.kaskada.v1alpha.GetCurrentSnapshotVersionRequest\x1a:.kaskada.kaskada.v1alpha.GetCurrentSnapshotVersionResponseB\x83\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x13\x43omputeServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')

_LONGQUERYSTATE = DESCRIPTOR.enum_types_by_name['LongQueryState']
LongQueryState = enum_type_wrapper.EnumTypeWrapper(_LONGQUERYSTATE)
LONG_QUERY_STATE_UNSPECIFIED = 0
LONG_QUERY_STATE_INITIAL = 1
LONG_QUERY_STATE_RUNNING = 2
LONG_QUERY_STATE_FINAL = 3


_FEATURESET = DESCRIPTOR.message_types_by_name['FeatureSet']
_FORMULA = DESCRIPTOR.message_types_by_name['Formula']
_COMPUTETABLE = DESCRIPTOR.message_types_by_name['ComputeTable']
_COMPUTETABLE_FILESET = _COMPUTETABLE.nested_types_by_name['FileSet']
_PLANHASH = DESCRIPTOR.message_types_by_name['PlanHash']
_RESULTPATHS = DESCRIPTOR.message_types_by_name['ResultPaths']
_GETCURRENTSNAPSHOTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['GetCurrentSnapshotVersionRequest']
_GETCURRENTSNAPSHOTVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['GetCurrentSnapshotVersionResponse']
_COMPILEREQUEST = DESCRIPTOR.message_types_by_name['CompileRequest']
_COMPILERESPONSE = DESCRIPTOR.message_types_by_name['CompileResponse']
_EXECUTEREQUEST = DESCRIPTOR.message_types_by_name['ExecuteRequest']
_EXECUTEREQUEST_LIMITS = _EXECUTEREQUEST.nested_types_by_name['Limits']
_EXECUTEREQUEST_COMPUTESNAPSHOTCONFIG = _EXECUTEREQUEST.nested_types_by_name['ComputeSnapshotConfig']
_EXECUTEREQUEST_OUTPUTTO = _EXECUTEREQUEST.nested_types_by_name['OutputTo']
_EXECUTERESPONSE = DESCRIPTOR.message_types_by_name['ExecuteResponse']
_EXECUTERESPONSE_PROGRESSINFORMATION = _EXECUTERESPONSE.nested_types_by_name['ProgressInformation']
_EXECUTERESPONSE_COMPUTESNAPSHOT = _EXECUTERESPONSE.nested_types_by_name['ComputeSnapshot']
_COMPILEREQUEST_EXPRESSIONKIND = _COMPILEREQUEST.enum_types_by_name['ExpressionKind']
FeatureSet = _reflection.GeneratedProtocolMessageType('FeatureSet', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESET,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.FeatureSet)
  })
_sym_db.RegisterMessage(FeatureSet)

Formula = _reflection.GeneratedProtocolMessageType('Formula', (_message.Message,), {
  'DESCRIPTOR' : _FORMULA,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Formula)
  })
_sym_db.RegisterMessage(Formula)

ComputeTable = _reflection.GeneratedProtocolMessageType('ComputeTable', (_message.Message,), {

  'FileSet' : _reflection.GeneratedProtocolMessageType('FileSet', (_message.Message,), {
    'DESCRIPTOR' : _COMPUTETABLE_FILESET,
    '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ComputeTable.FileSet)
    })
  ,
  'DESCRIPTOR' : _COMPUTETABLE,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ComputeTable)
  })
_sym_db.RegisterMessage(ComputeTable)
_sym_db.RegisterMessage(ComputeTable.FileSet)

PlanHash = _reflection.GeneratedProtocolMessageType('PlanHash', (_message.Message,), {
  'DESCRIPTOR' : _PLANHASH,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PlanHash)
  })
_sym_db.RegisterMessage(PlanHash)

ResultPaths = _reflection.GeneratedProtocolMessageType('ResultPaths', (_message.Message,), {
  'DESCRIPTOR' : _RESULTPATHS,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ResultPaths)
  })
_sym_db.RegisterMessage(ResultPaths)

GetCurrentSnapshotVersionRequest = _reflection.GeneratedProtocolMessageType('GetCurrentSnapshotVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTSNAPSHOTVERSIONREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetCurrentSnapshotVersionRequest)
  })
_sym_db.RegisterMessage(GetCurrentSnapshotVersionRequest)

GetCurrentSnapshotVersionResponse = _reflection.GeneratedProtocolMessageType('GetCurrentSnapshotVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTSNAPSHOTVERSIONRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetCurrentSnapshotVersionResponse)
  })
_sym_db.RegisterMessage(GetCurrentSnapshotVersionResponse)

CompileRequest = _reflection.GeneratedProtocolMessageType('CompileRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPILEREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CompileRequest)
  })
_sym_db.RegisterMessage(CompileRequest)

CompileResponse = _reflection.GeneratedProtocolMessageType('CompileResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPILERESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CompileResponse)
  })
_sym_db.RegisterMessage(CompileResponse)

ExecuteRequest = _reflection.GeneratedProtocolMessageType('ExecuteRequest', (_message.Message,), {

  'Limits' : _reflection.GeneratedProtocolMessageType('Limits', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEREQUEST_LIMITS,
    '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ExecuteRequest.Limits)
    })
  ,

  'ComputeSnapshotConfig' : _reflection.GeneratedProtocolMessageType('ComputeSnapshotConfig', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEREQUEST_COMPUTESNAPSHOTCONFIG,
    '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ExecuteRequest.ComputeSnapshotConfig)
    })
  ,

  'OutputTo' : _reflection.GeneratedProtocolMessageType('OutputTo', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEREQUEST_OUTPUTTO,
    '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ExecuteRequest.OutputTo)
    })
  ,
  'DESCRIPTOR' : _EXECUTEREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ExecuteRequest)
  })
_sym_db.RegisterMessage(ExecuteRequest)
_sym_db.RegisterMessage(ExecuteRequest.Limits)
_sym_db.RegisterMessage(ExecuteRequest.ComputeSnapshotConfig)
_sym_db.RegisterMessage(ExecuteRequest.OutputTo)

ExecuteResponse = _reflection.GeneratedProtocolMessageType('ExecuteResponse', (_message.Message,), {

  'ProgressInformation' : _reflection.GeneratedProtocolMessageType('ProgressInformation', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTERESPONSE_PROGRESSINFORMATION,
    '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ExecuteResponse.ProgressInformation)
    })
  ,

  'ComputeSnapshot' : _reflection.GeneratedProtocolMessageType('ComputeSnapshot', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTERESPONSE_COMPUTESNAPSHOT,
    '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ExecuteResponse.ComputeSnapshot)
    })
  ,
  'DESCRIPTOR' : _EXECUTERESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.compute_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ExecuteResponse)
  })
_sym_db.RegisterMessage(ExecuteResponse)
_sym_db.RegisterMessage(ExecuteResponse.ProgressInformation)
_sym_db.RegisterMessage(ExecuteResponse.ComputeSnapshot)

_COMPUTESERVICE = DESCRIPTOR.services_by_name['ComputeService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\023ComputeServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _LONGQUERYSTATE._serialized_start=4165
  _LONGQUERYSTATE._serialized_end=4303
  _FEATURESET._serialized_start=343
  _FEATURESET._serialized_end=439
  _FORMULA._serialized_start=441
  _FORMULA._serialized_end=537
  _COMPUTETABLE._serialized_start=540
  _COMPUTETABLE._serialized_end=917
  _COMPUTETABLE_FILESET._serialized_start=763
  _COMPUTETABLE_FILESET._serialized_end=917
  _PLANHASH._serialized_start=919
  _PLANHASH._serialized_end=949
  _RESULTPATHS._serialized_start=951
  _RESULTPATHS._serialized_end=986
  _GETCURRENTSNAPSHOTVERSIONREQUEST._serialized_start=988
  _GETCURRENTSNAPSHOTVERSIONREQUEST._serialized_end=1022
  _GETCURRENTSNAPSHOTVERSIONRESPONSE._serialized_start=1024
  _GETCURRENTSNAPSHOTVERSIONRESPONSE._serialized_end=1102
  _COMPILEREQUEST._serialized_start=1105
  _COMPILEREQUEST._serialized_end=1665
  _COMPILEREQUEST_EXPRESSIONKIND._serialized_start=1557
  _COMPILEREQUEST_EXPRESSIONKIND._serialized_end=1665
  _COMPILERESPONSE._serialized_start=1668
  _COMPILERESPONSE._serialized_end=2148
  _EXECUTEREQUEST._serialized_start=2151
  _EXECUTEREQUEST._serialized_end=3052
  _EXECUTEREQUEST_LIMITS._serialized_start=2697
  _EXECUTEREQUEST_LIMITS._serialized_end=2740
  _EXECUTEREQUEST_COMPUTESNAPSHOTCONFIG._serialized_start=2742
  _EXECUTEREQUEST_COMPUTESNAPSHOTCONFIG._serialized_end=2865
  _EXECUTEREQUEST_OUTPUTTO._serialized_start=2868
  _EXECUTEREQUEST_OUTPUTTO._serialized_end=3046
  _EXECUTERESPONSE._serialized_start=3055
  _EXECUTERESPONSE._serialized_end=4162
  _EXECUTERESPONSE_PROGRESSINFORMATION._serialized_start=3584
  _EXECUTERESPONSE_PROGRESSINFORMATION._serialized_end=3949
  _EXECUTERESPONSE_COMPUTESNAPSHOT._serialized_start=3952
  _EXECUTERESPONSE_COMPUTESNAPSHOT._serialized_end=4162
  _COMPUTESERVICE._serialized_start=4306
  _COMPUTESERVICE._serialized_end=4661
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v2alpha/query_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+kaskada/kaskada/v2alpha/query_service.proto\x12\x17kaskada.kaskada.v2alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$kaskada/kaskada/v1alpha/common.proto\x1a.kaskada/kaskada/v1alpha/fenl_diagnostics.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\x1a\x17validate/validate.proto\":\n\x0fLatestDataToken\x12\'\n\rdata_token_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x61taTokenId\"@\n\x11SpecificDataToken\x12+\n\rdata_token_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61taTokenId\"\xd4\x01\n\tDataToken\x12V\n\x11latest_data_token\x18\x01 \x01(\x0b\x32(.kaskada.kaskada.v2alpha.LatestDataTokenH\x00R\x0flatestDataToken\x12\\\n\x13specific_data_token\x18\x02 \x01(\x0b\x32*.kaskada.kaskada.v2alpha.SpecificDataTokenH\x00R\x11specificDataTokenB\x11\n\ndata_token\x12\x03\xf8\x42\x01\"Z\n\tQueryView\x12$\n\tview_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\x12\'\n\nexpression\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\"m\n\x12\x44\x65stinationRedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04port\"\x93\x01\n\x0b\x44\x65stination\x12;\n\x08\x61s_files\x18\x01 \x01(\x0b\x32 .kaskada.kaskada.v1alpha.AsFilesR\x07\x61sFiles\x12G\n\tredis_a_i\x18\x03 \x01(\x0b\x32+.kaskada.kaskada.v2alpha.DestinationRedisAIR\x07redisAI\"V\n\nAllResults\x12H\n\x12\x63hanged_since_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x63hangedSinceTime\"\xa0\x01\n\x0c\x46inalResults\x12H\n\x12\x63hanged_since_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x63hangedSinceTime\x12\x46\n\x11\x66inal_result_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inalResultTime\"\xa6\x01\n\x12\x46inalResultsAtTime\x12H\n\x12\x63hanged_since_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x63hangedSinceTime\x12\x46\n\x11\x66inal_result_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inalResultTime\"\xa0\x02\n\x0eResultBehavior\x12\x46\n\x0b\x61ll_results\x18\x01 \x01(\x0b\x32#.kaskada.kaskada.v2alpha.AllResultsH\x00R\nallResults\x12L\n\rfinal_results\x18\x02 \x01(\x0b\x32%.kaskada.kaskada.v2alpha.FinalResultsH\x00R\x0c\x66inalResults\x12`\n\x15\x66inal_results_at_time\x18\x03 \x01(\x0b\x32+.kaskada.kaskada.v2alpha.FinalResultsAtTimeH\x00R\x12\x66inalResultsAtTimeB\x16\n\x0fresult_behavior\x12\x03\xf8\x42\x01\"0\n\x0bQueryLimits\x12!\n\x0cpreview_rows\x18\x01 \x01(\x03R\x0bpreviewRows\"F\n\nQueryViews\x12\x38\n\x05views\x18\x01 \x03(\x0b\x32\".kaskada.kaskada.v2alpha.QueryViewR\x05views\"\x9a\x03\n\x0bQueryConfig\x12\x41\n\ndata_token\x18\x01 \x01(\x0b\x32\".kaskada.kaskada.v2alpha.DataTokenR\tdataToken\x12;\n\x05slice\x18\x02 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.SliceRequestR\x05slice\x12\x46\n\x0b\x64\x65stination\x18\x03 \x01(\x0b\x32$.kaskada.kaskada.v2alpha.DestinationR\x0b\x64\x65stination\x12P\n\x0fresult_behavior\x18\x04 \x01(\x0b\x32\'.kaskada.kaskada.v2alpha.ResultBehaviorR\x0eresultBehavior\x12<\n\x06limits\x18\x05 \x01(\x0b\x32$.kaskada.kaskada.v2alpha.QueryLimitsR\x06limits\x12\x33\n\x15\x65xperimental_features\x18\x06 \x03(\tR\x14\x65xperimentalFeatures\"\"\n\nCSVResults\x12\x14\n\x05paths\x18\x01 \x03(\tR\x05paths\"&\n\x0eParquetResults\x12\x14\n\x05paths\x18\x01 \x03(\tR\x05paths\"(\n\x10RedisBulkResults\x12\x14\n\x05paths\x18\x01 \x03(\tR\x05paths\"V\n\x0bQueryOutput\x12G\n\x0c\x66ile_results\x18\x01 \x01(\x0b\x32$.kaskada.kaskada.v1alpha.FileResultsR\x0b\x66ileResults\"\xda\x01\n\x0cQueryResults\x12<\n\x06output\x18\x01 \x01(\x0b\x32$.kaskada.kaskada.v2alpha.QueryOutputR\x06output\x12S\n\x10\x66\x65nl_diagnostics\x18\x02 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12\x37\n\x06schema\x18\x03 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaR\x06schema\"\xc3\x02\n\x0cQueryMetrics\x12@\n\x0etime_preparing\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\rtimePreparing\x12@\n\x0etime_computing\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\rtimeComputing\x12!\n\x0coutput_files\x18\x03 \x01(\x03R\x0boutputFiles\x12(\n\x10total_input_rows\x18\x04 \x01(\x03R\x0etotalInputRows\x12\x30\n\x14processed_input_rows\x18\x05 \x01(\x03R\x12processedInputRows\x12\x30\n\x14produced_output_rows\x18\x06 \x01(\x03R\x12producedOutputRows\"\xa3\x04\n\x05Query\x12\x1e\n\x08query_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07queryId\x12@\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\'\n\nexpression\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\x12>\n\x05views\x18\x05 \x01(\x0b\x32#.kaskada.kaskada.v2alpha.QueryViewsB\x03\xe0\x41\x03R\x05views\x12\x41\n\x06\x63onfig\x18\x06 \x01(\x0b\x32$.kaskada.kaskada.v2alpha.QueryConfigB\x03\xe0\x41\x03R\x06\x63onfig\x12>\n\x05state\x18\x07 \x01(\x0e\x32#.kaskada.kaskada.v2alpha.QueryStateB\x03\xe0\x41\x03R\x05state\x12\x44\n\x07results\x18\x08 \x01(\x0b\x32%.kaskada.kaskada.v2alpha.QueryResultsB\x03\xe0\x41\x03R\x07results\x12\x44\n\x07metrics\x18\t \x01(\x0b\x32%.kaskada.kaskada.v2alpha.QueryMetricsB\x03\xe0\x41\x03R\x07metrics\"\xcf\x01\n\x12\x43reateQueryRequest\x12\'\n\nexpression\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\x12\x39\n\x05views\x18\x02 \x01(\x0b\x32#.kaskada.kaskada.v2alpha.QueryViewsR\x05views\x12<\n\x06\x63onfig\x18\x03 \x01(\x0b\x32$.kaskada.kaskada.v2alpha.QueryConfigR\x06\x63onfig\x12\x17\n\x07\x64ry_run\x18\x04 \x01(\x08R\x06\x64ryRun\"\x9d\x01\n\x13\x43reateQueryResponse\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v2alpha.QueryR\x05query\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"8\n\x12\x44\x65leteQueryRequest\x12\"\n\x08query_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07queryId\"g\n\x13\x44\x65leteQueryResponse\x12P\n\x0frequest_details\x18\x01 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"^\n\x0fGetQueryRequest\x12\"\n\x08query_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07queryId\x12\'\n\x0fpresign_results\x18\x02 \x01(\x08R\x0epresignResults\"\x9a\x01\n\x10GetQueryResponse\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v2alpha.QueryR\x05query\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"t\n\x12ListQueriesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc9\x01\n\x13ListQueriesResponse\x12\x38\n\x07queries\x18\x01 \x03(\x0b\x32\x1e.kaskada.kaskada.v2alpha.QueryR\x07queries\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12P\n\x0frequest_details\x18\x03 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails*\xc5\x01\n\nQueryState\x12\x1b\n\x17QUERY_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14QUERY_STATE_COMPILED\x10\x01\x12\x19\n\x15QUERY_STATE_PREPARING\x10\x02\x12\x18\n\x14QUERY_STATE_PREPARED\x10\x03\x12\x19\n\x15QUERY_STATE_COMPUTING\x10\x04\x12\x17\n\x13QUERY_STATE_SUCCESS\x10\x05\x12\x17\n\x13QUERY_STATE_FAILURE\x10\x06\x32\xae\x04\n\x0cQueryService\x12\x83\x01\n\x0b\x43reateQuery\x12+.kaskada.kaskada.v2alpha.CreateQueryRequest\x1a,.kaskada.kaskada.v2alpha.CreateQueryResponse\"\x19\x82\xd3\xe4\x93\x02\x13:\x01*\"\x0e/v2alpha/query\x12\x8d\x01\n\x0b\x44\x65leteQuery\x12+.kaskada.kaskada.v2alpha.DeleteQueryRequest\x1a,.kaskada.kaskada.v2alpha.DeleteQueryResponse\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/v2alpha/query/{query_id=*}\x12\x84\x01\n\x08GetQuery\x12(.kaskada.kaskada.v2alpha.GetQueryRequest\x1a).kaskada.kaskada.v2alpha.GetQueryResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v2alpha/query/{query_id=*}\x12\x80\x01\n\x0bListQueries\x12+.kaskada.kaskada.v2alpha.ListQueriesRequest\x1a,.kaskada.kaskada.v2alpha.ListQueriesResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v2alpha/queryB\x81\x02\n\x1b\x63om.kaskada.kaskada.v2alphaB\x11QueryServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v2alpha;kaskadav2alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V2alpha\xca\x02\x17Kaskada\\Kaskada\\V2alpha\xe2\x02#Kaskada\\Kaskada\\V2alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V2alphab\x06proto3')

_QUERYSTATE = DESCRIPTOR.enum_types_by_name['QueryState']
QueryState = enum_type_wrapper.EnumTypeWrapper(_QUERYSTATE)
QUERY_STATE_UNSPECIFIED = 0
QUERY_STATE_COMPILED = 1
QUERY_STATE_PREPARING = 2
QUERY_STATE_PREPARED = 3
QUERY_STATE_COMPUTING = 4
QUERY_STATE_SUCCESS = 5
QUERY_STATE_FAILURE = 6


_LATESTDATATOKEN = DESCRIPTOR.message_types_by_name['LatestDataToken']
_SPECIFICDATATOKEN = DESCRIPTOR.message_types_by_name['SpecificDataToken']
_DATATOKEN = DESCRIPTOR.message_types_by_name['DataToken']
_QUERYVIEW = DESCRIPTOR.message_types_by_name['QueryView']
_DESTINATIONREDISAI = DESCRIPTOR.message_types_by_name['DestinationRedisAI']
_DESTINATION = DESCRIPTOR.message_types_by_name['Destination']
_ALLRESULTS = DESCRIPTOR.message_types_by_name['AllResults']
_FINALRESULTS = DESCRIPTOR.message_types_by_name['FinalResults']
_FINALRESULTSATTIME = DESCRIPTOR.message_types_by_name['FinalResultsAtTime']
_RESULTBEHAVIOR = DESCRIPTOR.message_types_by_name['ResultBehavior']
_QUERYLIMITS = DESCRIPTOR.message_types_by_name['QueryLimits']
_QUERYVIEWS = DESCRIPTOR.message_types_by_name['QueryViews']
_QUERYCONFIG = DESCRIPTOR.message_types_by_name['QueryConfig']
_CSVRESULTS = DESCRIPTOR.message_types_by_name['CSVResults']
_PARQUETRESULTS = DESCRIPTOR.message_types_by_name['ParquetResults']
_REDISBULKRESULTS = DESCRIPTOR.message_types_by_name['RedisBulkResults']
_QUERYOUTPUT = DESCRIPTOR.message_types_by_name['QueryOutput']
_QUERYRESULTS = DESCRIPTOR.message_types_by_name['QueryResults']
_QUERYMETRICS = DESCRIPTOR.message_types_by_name['QueryMetrics']
_QUERY = DESCRIPTOR.message_types_by_name['Query']
_CREATEQUERYREQUEST = DESCRIPTOR.message_types_by_name['CreateQueryRequest']
_CREATEQUERYRESPONSE = DESCRIPTOR.message_types_by_name['CreateQueryResponse']
_DELETEQUERYREQUEST = DESCRIPTOR.message_types_by_name['DeleteQueryRequest']
_DELETEQUERYRESPONSE = DESCRIPTOR.message_types_by_name['DeleteQueryResponse']
_GETQUERYREQUEST = DESCRIPTOR.message_types_by_name['GetQueryRequest']
_GETQUERYRESPONSE = DESCRIPTOR.message_types_by_name['GetQueryResponse']
_LISTQUERIESREQUEST = DESCRIPTOR.message_types_by_name['ListQueriesRequest']
_LISTQUERIESRESPONSE = DESCRIPTOR.message_types_by_name['ListQueriesResponse']
LatestDataToken = _reflection.GeneratedProtocolMessageType('LatestDataToken', (_message.Message,), {
  'DESCRIPTOR' : _LATESTDATATOKEN,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.LatestDataToken)
  })
_sym_db.RegisterMessage(LatestDataToken)

SpecificDataToken = _reflection.GeneratedProtocolMessageType('SpecificDataToken', (_message.Message,), {
  'DESCRIPTOR' : _SPECIFICDATATOKEN,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.SpecificDataToken)
  })
_sym_db.RegisterMessage(SpecificDataToken)

DataToken = _reflection.GeneratedProtocolMessageType('DataToken', (_message.Message,), {
  'DESCRIPTOR' : _DATATOKEN,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.DataToken)
  })
_sym_db.RegisterMessage(DataToken)

QueryView = _reflection.GeneratedProtocolMessageType('QueryView', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVIEW,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.QueryView)
  })
_sym_db.RegisterMessage(QueryView)

DestinationRedisAI = _reflection.GeneratedProtocolMessageType('DestinationRedisAI', (_message.Message,), {
  'DESCRIPTOR' : _DESTINATIONREDISAI,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.DestinationRedisAI)
  })
_sym_db.RegisterMessage(DestinationRedisAI)

Destination = _reflection.GeneratedProtocolMessageType('Destination', (_message.Message,), {
  'DESCRIPTOR' : _DESTINATION,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.Destination)
  })
_sym_db.RegisterMessage(Destination)

AllResults = _reflection.GeneratedProtocolMessageType('AllResults', (_message.Message,), {
  'DESCRIPTOR' : _ALLRESULTS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.AllResults)
  })
_sym_db.RegisterMessage(AllResults)

FinalResults = _reflection.GeneratedProtocolMessageType('FinalResults', (_message.Message,), {
  'DESCRIPTOR' : _FINALRESULTS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.FinalResults)
  })
_sym_db.RegisterMessage(FinalResults)

FinalResultsAtTime = _reflection.GeneratedProtocolMessageType('FinalResultsAtTime', (_message.Message,), {
  'DESCRIPTOR' : _FINALRESULTSATTIME,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.FinalResultsAtTime)
  })
_sym_db.RegisterMessage(FinalResultsAtTime)

ResultBehavior = _reflection.GeneratedProtocolMessageType('ResultBehavior', (_message.Message,), {
  'DESCRIPTOR' : _RESULTBEHAVIOR,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.ResultBehavior)
  })
_sym_db.RegisterMessage(ResultBehavior)

QueryLimits = _reflection.GeneratedProtocolMessageType('QueryLimits', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLIMITS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.QueryLimits)
  })
_sym_db.RegisterMessage(QueryLimits)

QueryViews = _reflection.GeneratedProtocolMessageType('QueryViews', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVIEWS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.QueryViews)
  })
_sym_db.RegisterMessage(QueryViews)

QueryConfig = _reflection.GeneratedProtocolMessageType('QueryConfig', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONFIG,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.QueryConfig)
  })
_sym_db.RegisterMessage(QueryConfig)

CSVResults = _reflection.GeneratedProtocolMessageType('CSVResults', (_message.Message,), {
  'DESCRIPTOR' : _CSVRESULTS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.CSVResults)
  })
_sym_db.RegisterMessage(CSVResults)

ParquetResults = _reflection.GeneratedProtocolMessageType('ParquetResults', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETRESULTS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.ParquetResults)
  })
_sym_db.RegisterMessage(ParquetResults)

RedisBulkResults = _reflection.GeneratedProtocolMessageType('RedisBulkResults', (_message.Message,), {
  'DESCRIPTOR' : _REDISBULKRESULTS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.RedisBulkResults)
  })
_sym_db.RegisterMessage(RedisBulkResults)

QueryOutput = _reflection.GeneratedProtocolMessageType('QueryOutput', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOUTPUT,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.QueryOutput)
  })
_sym_db.RegisterMessage(QueryOutput)

QueryResults = _reflection.GeneratedProtocolMessageType('QueryResults', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESULTS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.QueryResults)
  })
_sym_db.RegisterMessage(QueryResults)

QueryMetrics = _reflection.GeneratedProtocolMessageType('QueryMetrics', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMETRICS,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.QueryMetrics)
  })
_sym_db.RegisterMessage(QueryMetrics)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.Query)
  })
_sym_db.RegisterMessage(Query)

CreateQueryRequest = _reflection.GeneratedProtocolMessageType('CreateQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEQUERYREQUEST,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.CreateQueryRequest)
  })
_sym_db.RegisterMessage(CreateQueryRequest)

CreateQueryResponse = _reflection.GeneratedProtocolMessageType('CreateQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEQUERYRESPONSE,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.CreateQueryResponse)
  })
_sym_db.RegisterMessage(CreateQueryResponse)

DeleteQueryRequest = _reflection.GeneratedProtocolMessageType('DeleteQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEQUERYREQUEST,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.DeleteQueryRequest)
  })
_sym_db.RegisterMessage(DeleteQueryRequest)

DeleteQueryResponse = _reflection.GeneratedProtocolMessageType('DeleteQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEQUERYRESPONSE,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.DeleteQueryResponse)
  })
_sym_db.RegisterMessage(DeleteQueryResponse)

GetQueryRequest = _reflection.GeneratedProtocolMessageType('GetQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYREQUEST,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.GetQueryRequest)
  })
_sym_db.RegisterMessage(GetQueryRequest)

GetQueryResponse = _reflection.GeneratedProtocolMessageType('GetQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYRESPONSE,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.GetQueryResponse)
  })
_sym_db.RegisterMessage(GetQueryResponse)

ListQueriesRequest = _reflection.GeneratedProtocolMessageType('ListQueriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESREQUEST,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.ListQueriesRequest)
  })
_sym_db.RegisterMessage(ListQueriesRequest)

ListQueriesResponse = _reflection.GeneratedProtocolMessageType('ListQueriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESRESPONSE,
  '__module__' : 'kaskada.kaskada.v2alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v2alpha.ListQueriesResponse)
  })
_sym_db.RegisterMessage(ListQueriesResponse)

_QUERYSERVICE = DESCRIPTOR.services_by_name['QueryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v2alphaB\021QueryServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v2alpha;kaskadav2alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V2alpha\312\002\027Kaskada\\Kaskada\\V2alpha\342\002#Kaskada\\Kaskada\\V2alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V2alpha'
  _LATESTDATATOKEN.fields_by_name['data_token_id']._options = None
  _LATESTDATATOKEN.fields_by_name['data_token_id']._serialized_options = b'\340A\003'
  _SPECIFICDATATOKEN.fields_by_name['data_token_id']._options = None
  _SPECIFICDATATOKEN.fields_by_name['data_token_id']._serialized_options = b'\372B\004r\002\020\001'
  _DATATOKEN.oneofs_by_name['data_token']._options = None
  _DATATOKEN.oneofs_by_name['data_token']._serialized_options = b'\370B\001'
  _QUERYVIEW.fields_by_name['view_name']._options = None
  _QUERYVIEW.fields_by_name['view_name']._serialized_options = b'\372B\004r\002\020\001'
  _QUERYVIEW.fields_by_name['expression']._options = None
  _QUERYVIEW.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _DESTINATIONREDISAI.fields_by_name['db']._options = None
  _DESTINATIONREDISAI.fields_by_name['db']._serialized_options = b'\372B\006\032\004\030\017(\000'
  _DESTINATIONREDISAI.fields_by_name['host']._options = None
  _DESTINATIONREDISAI.fields_by_name['host']._serialized_options = b'\372B\004r\002\020\001'
  _DESTINATIONREDISAI.fields_by_name['port']._options = None
  _DESTINATIONREDISAI.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _RESULTBEHAVIOR.oneofs_by_name['result_behavior']._options = None
  _RESULTBEHAVIOR.oneofs_by_name['result_behavior']._serialized_options = b'\370B\001'
  _QUERY.fields_by_name['query_id']._options = None
  _QUERY.fields_by_name['query_id']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['create_time']._options = None
  _QUERY.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['update_time']._options = None
  _QUERY.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['expression']._options = None
  _QUERY.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _QUERY.fields_by_name['views']._options = None
  _QUERY.fields_by_name['views']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['config']._options = None
  _QUERY.fields_by_name['config']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['state']._options = None
  _QUERY.fields_by_name['state']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['results']._options = None
  _QUERY.fields_by_name['results']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['metrics']._options = None
  _QUERY.fields_by_name['metrics']._serialized_options = b'\340A\003'
  _CREATEQUERYREQUEST.fields_by_name['expression']._options = None
  _CREATEQUERYREQUEST.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEQUERYREQUEST.fields_by_name['query_id']._options = None
  _DELETEQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETQUERYREQUEST.fields_by_name['query_id']._options = None
  _GETQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\372B\004r\002\020\001'
  _LISTQUERIESREQUEST.fields_by_name['page_size']._options = None
  _LISTQUERIESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _QUERYSERVICE.methods_by_name['CreateQuery']._options = None
  _QUERYSERVICE.methods_by_name['CreateQuery']._serialized_options = b'\202\323\344\223\002\023:\001*\"\016/v2alpha/query'
  _QUERYSERVICE.methods_by_name['DeleteQuery']._options = None
  _QUERYSERVICE.methods_by_name['DeleteQuery']._serialized_options = b'\202\323\344\223\002\035*\033/v2alpha/query/{query_id=*}'
  _QUERYSERVICE.methods_by_name['GetQuery']._options = None
  _QUERYSERVICE.methods_by_name['GetQuery']._serialized_options = b'\202\323\344\223\002\035\022\033/v2alpha/query/{query_id=*}'
  _QUERYSERVICE.methods_by_name['ListQueries']._options = None
  _QUERYSERVICE.methods_by_name['ListQueries']._serialized_options = b'\202\323\344\223\002\020\022\016/v2alpha/query'
  _QUERYSTATE._serialized_start=4701
  _QUERYSTATE._serialized_end=4898
  _LATESTDATATOKEN._serialized_start=349
  _LATESTDATATOKEN._serialized_end=407
  _SPECIFICDATATOKEN._serialized_start=409
  _SPECIFICDATATOKEN._serialized_end=473
  _DATATOKEN._serialized_start=476
  _DATATOKEN._serialized_end=688
  _QUERYVIEW._serialized_start=690
  _QUERYVIEW._serialized_end=780
  _DESTINATIONREDISAI._serialized_start=782
  _DESTINATIONREDISAI._serialized_end=891
  _DESTINATION._serialized_start=894
  _DESTINATION._serialized_end=1041
  _ALLRESULTS._serialized_start=1043
  _ALLRESULTS._serialized_end=1129
  _FINALRESULTS._serialized_start=1132
  _FINALRESULTS._serialized_end=1292
  _FINALRESULTSATTIME._serialized_start=1295
  _FINALRESULTSATTIME._serialized_end=1461
  _RESULTBEHAVIOR._serialized_start=1464
  _RESULTBEHAVIOR._serialized_end=1752
  _QUERYLIMITS._serialized_start=1754
  _QUERYLIMITS._serialized_end=1802
  _QUERYVIEWS._serialized_start=1804
  _QUERYVIEWS._serialized_end=1874
  _QUERYCONFIG._serialized_start=1877
  _QUERYCONFIG._serialized_end=2287
  _CSVRESULTS._serialized_start=2289
  _CSVRESULTS._serialized_end=2323
  _PARQUETRESULTS._serialized_start=2325
  _PARQUETRESULTS._serialized_end=2363
  _REDISBULKRESULTS._serialized_start=2365
  _REDISBULKRESULTS._serialized_end=2405
  _QUERYOUTPUT._serialized_start=2407
  _QUERYOUTPUT._serialized_end=2493
  _QUERYRESULTS._serialized_start=2496
  _QUERYRESULTS._serialized_end=2714
  _QUERYMETRICS._serialized_start=2717
  _QUERYMETRICS._serialized_end=3040
  _QUERY._serialized_start=3043
  _QUERY._serialized_end=3590
  _CREATEQUERYREQUEST._serialized_start=3593
  _CREATEQUERYREQUEST._serialized_end=3800
  _CREATEQUERYRESPONSE._serialized_start=3803
  _CREATEQUERYRESPONSE._serialized_end=3960
  _DELETEQUERYREQUEST._serialized_start=3962
  _DELETEQUERYREQUEST._serialized_end=4018
  _DELETEQUERYRESPONSE._serialized_start=4020
  _DELETEQUERYRESPONSE._serialized_end=4123
  _GETQUERYREQUEST._serialized_start=4125
  _GETQUERYREQUEST._serialized_end=4219
  _GETQUERYRESPONSE._serialized_start=4222
  _GETQUERYRESPONSE._serialized_end=4376
  _LISTQUERIESREQUEST._serialized_start=4378
  _LISTQUERIESREQUEST._serialized_end=4494
  _LISTQUERIESRESPONSE._serialized_start=4497
  _LISTQUERIESRESPONSE._serialized_end=4698
  _QUERYSERVICE._serialized_start=4901
  _QUERYSERVICE._serialized_end=5459
# @@protoc_insertion_point(module_scope)



import logging
import sys
from typing import Optional, Union

import grpc

import kaskada.kaskada.v1alpha.view_service_pb2 as view_pb
from kaskada.client import Client, get_client
from kaskada.utils import handleException, handleGrpcError

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logger = logging.getLogger(__name__)


def get_view_name(
    view: Union[view_pb.View, view_pb.CreateViewResponse, view_pb.GetViewResponse, str]
) -> str:
    view_name = None
    if isinstance(view, view_pb.View):
        view_name = view.view_name
    elif isinstance(view, view_pb.CreateViewResponse) or isinstance(
        view, view_pb.GetViewResponse
    ):
        view_name = view.view.view_name
    elif isinstance(view, str):
        view_name = view

    if view_name is None:
        raise Exception(
            "invalid view parameter provided. \
                the view parameter must be the view object, view response from the SDK, or the view name"
        )

    return view_name


def list_views(
    search: Optional[str] = None, client: Optional[Client] = None
) -> view_pb.ListViewsResponse:
    """
    Lists all the views the user has access to

    Args:
        search (str, optional): The search parameter to filter list by. Defaults to None.
        client (Client, optional): The Kaskada Client. Defaults to kaskada.KASKADA_DEFAULT_CLIENT.

    Returns:
        view_pb.ListViewsResponse: Response from the API
    """

    try:
        client = get_client(client)
        req = view_pb.ListViewsRequest(
            search=search,
        )
        logger.debug(f"List Views Request: {req}")
        return client.view_stub.ListViews(req, metadata=client.get_metadata())
    except grpc.RpcError as e:
        handleGrpcError(e)
    except Exception as e:
        handleException(e)


def get_view(
    view: Union[view_pb.View, view_pb.CreateViewResponse, view_pb.GetViewResponse, str],
    client: Optional[Client] = None,
) -> view_pb.GetViewResponse:
    """
    Gets a view by name

    Args:
        view (Union[view_pb.View, view_pb.CreateViewResponse, view_pb.GetViewResponse, str]): The target view object
        client (Client, optional): The Kaskada Client. Defaults to kaskada.KASKADA_DEFAULT_CLIENT.

    Returns:
        view_pb.GetViewResponse: Response from the API
    """

    try:
        view_name = get_view_name(view)
        client = get_client(client)
        req = view_pb.GetViewRequest(view_name=view_name)
        logger.debug(f"Get View Request: {req}")
        return client.view_stub.GetView(req, metadata=client.get_metadata())
    except grpc.RpcError as e:
        handleGrpcError(e)
    except Exception as e:
        handleException(e)


def create_view(
    view_name: str, expression: str, client: Optional[Client] = None
) -> view_pb.CreateViewResponse:
    """
    Creates a view with a name and expression

    Args:
        view_name (str): The view name
        expression (str): The view fenl expression
        client (Client, optional): The Kaskada Client. Defaults to kaskada.KASKADA_DEFAULT_CLIENT.

    Returns:
        view_pb.CreateViewResponse: Response from the API
    """

    try:
        client = get_client(client)
        req = view_pb.CreateViewRequest(
            view=view_pb.View(view_name=view_name, expression=expression)
        )
        logger.debug(f"Create View Request: {req}")
        return client.view_stub.CreateView(req, metadata=client.get_metadata())
    except grpc.RpcError as e:
        handleGrpcError(e)
    except Exception as e:
        handleException(e)


def delete_view(
    view: Union[view_pb.View, view_pb.CreateViewResponse, view_pb.GetViewResponse, str],
    client: Optional[Client] = None,
    force: bool = False,
) -> view_pb.DeleteViewResponse:
    """
    Deletes a view

    Args:
        view (Union[view_pb.View, view_pb.CreateViewResponse, view_pb.GetViewResponse, str]): The target view object
        client (Client, optional): The Kaskada Client. Defaults to kaskada.KASKADA_DEFAULT_CLIENT.

    Returns:
        view_pb.DeleteViewResponse: Response from the API
    """

    try:
        view_name = get_view_name(view)
        client = get_client(client)
        req = view_pb.DeleteViewRequest(view_name=view_name, force=force)
        logger.debug(f"Delete View Request: {req}")
        return client.view_stub.DeleteView(req, metadata=client.get_metadata())
    except grpc.RpcError as e:
        handleGrpcError(e)
    except Exception as e:
        handleException(e)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from kaskada.kaskada.v1alpha import compute_service_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2


class ComputeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Compile = channel.unary_unary(
                '/kaskada.kaskada.v1alpha.ComputeService/Compile',
                request_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.CompileRequest.SerializeToString,
                response_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.CompileResponse.FromString,
                )
        self.Execute = channel.unary_stream(
                '/kaskada.kaskada.v1alpha.ComputeService/Execute',
                request_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.ExecuteRequest.SerializeToString,
                response_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.ExecuteResponse.FromString,
                )
        self.GetCurrentSnapshotVersion = channel.unary_unary(
                '/kaskada.kaskada.v1alpha.ComputeService/GetCurrentSnapshotVersion',
                request_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.GetCurrentSnapshotVersionRequest.SerializeToString,
                response_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.GetCurrentSnapshotVersionResponse.FromString,
                )


class ComputeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Compile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Execute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCurrentSnapshotVersion(self, request, context):
        """Gets the current snapshot version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ComputeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Compile': grpc.unary_unary_rpc_method_handler(
                    servicer.Compile,
                    request_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.CompileRequest.FromString,
                    response_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.CompileResponse.SerializeToString,
            ),
            'Execute': grpc.unary_stream_rpc_method_handler(
                    servicer.Execute,
                    request_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.ExecuteRequest.FromString,
                    response_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.ExecuteResponse.SerializeToString,
            ),
            'GetCurrentSnapshotVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentSnapshotVersion,
                    request_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.GetCurrentSnapshotVersionRequest.FromString,
                    response_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.GetCurrentSnapshotVersionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaskada.kaskada.v1alpha.ComputeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ComputeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Compile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.kaskada.v1alpha.ComputeService/Compile',
            kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.CompileRequest.SerializeToString,
            kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.CompileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Execute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kaskada.kaskada.v1alpha.ComputeService/Execute',
            kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.ExecuteRequest.SerializeToString,
            kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.ExecuteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCurrentSnapshotVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.kaskada.v1alpha.ComputeService/GetCurrentSnapshotVersion',
            kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.GetCurrentSnapshotVersionRequest.SerializeToString,
            kaskada_dot_kaskada_dot_v1alpha_dot_compute__service__pb2.GetCurrentSnapshotVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/destinations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*kaskada/kaskada/v1alpha/destinations.proto\x12\x17kaskada.kaskada.v1alpha\"\xf1\x01\n\x16ObjectStoreDestination\x12R\n\x06\x66ormat\x18\x01 \x01(\x0e\x32:.kaskada.kaskada.v1alpha.ObjectStoreDestination.FileFormatR\x06\x66ormat\x12*\n\x11output_prefix_uri\x18\x02 \x01(\tR\x0foutputPrefixUri\"W\n\nFileFormat\x12\x1b\n\x17\x46ILE_FORMAT_UNSPECIFIED\x10\x00\x12\x17\n\x13\x46ILE_FORMAT_PARQUET\x10\x01\x12\x13\n\x0f\x46ILE_FORMAT_CSV\x10\x02\"\xa7\x02\n\x10RedisDestination\x12\x1b\n\thost_name\x18\x01 \x01(\tR\x08hostName\x12\x12\n\x04port\x18\x02 \x01(\x05R\x04port\x12\x17\n\x07use_tls\x18\x03 \x01(\x08R\x06useTls\x12\'\n\x0f\x64\x61tabase_number\x18\x04 \x01(\x05R\x0e\x64\x61tabaseNumber\x12\x1a\n\x08password\x18\x05 \x01(\tR\x08password\x12\x19\n\x08tls_cert\x18\x06 \x01(\tR\x07tlsCert\x12\x17\n\x07tls_key\x18\x07 \x01(\tR\x06tlsKey\x12\x1e\n\x0btls_ca_cert\x18\x08 \x01(\tR\ttlsCaCert\x12\x30\n\x14insecure_skip_verify\x18\t \x01(\x08R\x12insecureSkipVerifyB\x81\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x11\x44\x65stinationsProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_OBJECTSTOREDESTINATION = DESCRIPTOR.message_types_by_name['ObjectStoreDestination']
_REDISDESTINATION = DESCRIPTOR.message_types_by_name['RedisDestination']
_OBJECTSTOREDESTINATION_FILEFORMAT = _OBJECTSTOREDESTINATION.enum_types_by_name['FileFormat']
ObjectStoreDestination = _reflection.GeneratedProtocolMessageType('ObjectStoreDestination', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTSTOREDESTINATION,
  '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ObjectStoreDestination)
  })
_sym_db.RegisterMessage(ObjectStoreDestination)

RedisDestination = _reflection.GeneratedProtocolMessageType('RedisDestination', (_message.Message,), {
  'DESCRIPTOR' : _REDISDESTINATION,
  '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.RedisDestination)
  })
_sym_db.RegisterMessage(RedisDestination)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\021DestinationsProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _OBJECTSTOREDESTINATION._serialized_start=72
  _OBJECTSTOREDESTINATION._serialized_end=313
  _OBJECTSTOREDESTINATION_FILEFORMAT._serialized_start=226
  _OBJECTSTOREDESTINATION_FILEFORMAT._serialized_end=313
  _REDISDESTINATION._serialized_start=316
  _REDISDESTINATION._serialized_end=611
# @@protoc_insertion_point(module_scope)



import functools
import logging
import os
import shutil
import sys
from pathlib import Path

import requests
from github import Github

import kaskada.api.api_utils

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logger = logging.getLogger(__name__)


class LocalRelease(object):
    """Configuration details for a local release. Mostly used for binary paths."""

    def __init__(
        self, download_path: Path, manager_path: Path, engine_path: Path
    ) -> None:
        self._download_path = download_path
        self._manager_path = manager_path
        self._engine_path = engine_path


class ReleaseClient(object):
    ORGANIZATION = "kaskada-ai"
    REPO_NAME = "kaskada"
    # In case the repository is private, an authorized access token is required.
    GITHUB_ACCESS_TOKEN_ENV = "GITHUB_ACCESS_TOKEN"
    ASSETS_API_ENDPOINT = "https://api.github.com/repos/{}/{}/releases/assets".format(
        ORGANIZATION, REPO_NAME
    )

    def __init__(self) -> None:
        super().__init__()
        self._platform_details = kaskada.api.api_utils.get_platform_details()
        # Private repository access
        access_token = os.getenv(self.GITHUB_ACCESS_TOKEN_ENV)
        self._github = Github(access_token)

    def download_latest_release(
        self, download_path: Path, manager_bin_name: str, engine_bin_name: str
    ) -> LocalRelease:
        """Downloads the latest version of the kaskada-manager and kaskada-engine.

        Args:
            download_path (Path): The local download path
            manager_bin_name (str): The name of the manager binary to save in download path
            engine_bin_name (str): The name of the engine binary to save in download path

        Raises:
            RuntimeError: unable to get release assets

        Returns:
            Tuple[str, str]: manager path and engine path
        """
        manager_name = f"kaskada-manager-{self._platform_details}"
        logger.debug(f"Looking for manager binary name: {manager_name}")
        engine_name = f"kaskada-engine-{self._platform_details}"
        logger.debug(f"Looking for engine binary name: {engine_name}")
        session = requests.Session()
        access_token = os.getenv(self.GITHUB_ACCESS_TOKEN_ENV)
        if access_token is not None:
            logger.debug("Access token set. Using Github Access token.")
            session.headers["Authorization"] = f"token {access_token}"

        repo = self._github.get_repo(f"{self.ORGANIZATION}/{self.REPO_NAME}")
        latest_release = repo.get_latest_release()
        logger.info(f"Using latest release version: {latest_release.tag_name}")
        download_path = download_path / latest_release.tag_name
        download_path.mkdir(parents=True, exist_ok=True)
        logger.debug(f"Download path: {download_path}")
        assets = latest_release.get_assets()

        manager_path, engine_path = (None, None)
        for asset in assets:
            url = f"{self.ASSETS_API_ENDPOINT}/{asset.id}"
            if asset.name == manager_name:
                manager_path = self.__download(
                    session,
                    url,
                    download_path / manager_bin_name,
                    asset.name,
                    file_size=asset.size,
                )
            elif asset.name == engine_name:
                engine_path = self.__download(
                    session,
                    url,
                    download_path / engine_bin_name,
                    asset.name,
                    file_size=asset.size,
                )

        if manager_path is None:
            raise RuntimeError(f"unable to download manager binary: {manager_name}")
        if engine_path is None:
            raise RuntimeError(f"unable to download engine binary: {engine_name}")
        return LocalRelease(download_path, manager_path, engine_path)

    def __download(
        self,
        r: requests.Session,
        url: str,
        download_path: Path,
        description: str,
        file_size: int = 0,
    ) -> Path:
        """Downloads a URL as an application/octet-stream

        Args:
            r (requests.Session): The request session
            url (str): The targget URL
            download_path (Path): The local path to stream write the file
            description (str): The description to render during download
            file_size (int, optional): The file size if known ahead of time. Defaults to response content size or 0.

        Raises:
            RuntimeError: Unable to download the target URL due to non 200 error code.

        Returns:
            Path: The local download path
        """
        logger.debug(
            f"Downloading: {url} to {download_path}. Content Size: {file_size}"
        )
        # A naive cache hit algorithm where a hit is if the file exists and is the same size as the asset.
        if download_path.exists() and download_path.stat().st_size == file_size:
            logger.info(f"Skipping download. Using binary: {download_path}")
            return download_path
        # Request header to get the binary
        r.headers["Accept"] = "application/octet-stream"
        response = r.get(url, stream=True, allow_redirects=True)
        if response.status_code != 200:
            response.raise_for_status()  # If there was an HTTP error, raise that first otherwise generic error.
            raise RuntimeError(
                f"request to download binary failed with status code: {response.status_code}"
            )
        if (
            file_size == 0
        ):  # The file size is only used for the progress bar visualization.
            file_size = int(r.headers.get("Content-Length", 0))
        desc = "(Unknown total file size)" if file_size == 0 else description
        response.raw.read = functools.partial(
            response.raw.read, decode_content=True
        )  # Decompress if needed
        from tqdm.auto import tqdm

        with tqdm.wrapattr(
            response.raw, "read", total=file_size, desc=desc
        ) as r_raw:  # Define the progress bar
            with download_path.open(
                "wb"
            ) as f:  # Start downloading the raw response as the binary
                shutil.copyfileobj(r_raw, f)
        logger.debug(f"Successfully downloaded to: {download_path}")
        return download_path



# pylint: skip-file

import builtins
import inspect
import io
import logging
import pprint
import sys

import html5lib
import pkg_resources
from domonic.ext.html5lib_ import getTreeBuilder
from domonic.html import a, button, div, pre, script, style, table, td, th, tr
from domonic.utils import Utils

import kaskada.formatters_shared as shared
from kaskada.formatters_helpers import (
    appendChildIfNotNone,
    appendHtmlObjTableRowIfAttrExists,
    get_classname,
    get_properties,
    get_schema_dataframe,
    html_obj_id_row,
    html_obj_table_row,
    html_table_row,
)

_LOGGER = logging.getLogger(__name__)


def in_ipython() -> bool:
    """
    Checks to see if running in an iPython environment
    """
    return getattr(builtins, "__IPYTHON__", False)


def get_query_response_content(resp_obj):
    resultsExist = False
    details = table(_class="kda_table")

    state_enum_descriptor = resp_obj.DESCRIPTOR.enum_types_by_name.get("State")
    state = state_enum_descriptor.values_by_number.get(resp_obj.state).name
    details.appendChild(html_table_row("state", state.replace("STATE_", "")))

    if hasattr(resp_obj, "query_id"):
        details.appendChild(html_table_row("query_id", resp_obj.query_id))

    if hasattr(resp_obj, "metrics") and resp_obj.state > 1:
        metrics = shared.get_metrics_html(resp_obj.metrics)
        details.appendChild(html_table_row("metrics", metrics))

    if hasattr(resp_obj, "file_results"):
        nested_table = table(_class="kda_table")
        details.appendChild(html_table_row("file_results", nested_table))
        nested_table.appendChild(tr(th("index"), th("path")))
        for i in range(len(resp_obj.file_results.paths)):
            path = resp_obj.file_results.paths[i]
            appendChildIfNotNone(nested_table, tr(td(pre(i)), td(a(path, _href=path))))
        resultsExist = True
    elif hasattr(resp_obj, "redis_bulk"):
        nested_table = table(_class="kda_table")
        details.appendChild(html_table_row("redis_bulk", nested_table))
        nested_table.appendChild(tr(th("index"), th("path")))
        for i in range(len(resp_obj.redis_bulk.paths)):
            path = resp_obj.redis_bulk.paths[i]
            appendChildIfNotNone(nested_table, tr(td(pre(i)), td(a(path, _href=path))))
        resultsExist = True

    (
        can_execute,
        has_errors,
        nested_details,
        diagnostics,
    ) = shared.get_analysis_and_diagnostics_tables(resp_obj)
    details.appendChild(html_table_row("analysis", nested_details))

    schema = None
    if resp_obj.HasField("analysis"):
        schema_df = get_schema_dataframe(resp_obj.analysis)
        if schema_df is not None:
            schema = convert_df_to_domonic(schema_df)
            details.appendChild(html_obj_table_row("schema", "(see Schema tab)"))

    if resultsExist and hasattr(resp_obj, "config"):
        appendHtmlObjTableRowIfAttrExists(details, resp_obj.config, "data_token_id")
        if resp_obj.config.HasField("slice_request"):
            details.appendChild(
                html_table_row(
                    "slice_request",
                    shared.get_slice_request_html(resp_obj.config.slice_request),
                )
            )
        else:
            details.appendChild(
                html_table_row("slice_request", shared.get_slice_request_html(None))
            )

    appendChildIfNotNone(
        details, shared.get_request_details_table_row_if_exists(resp_obj)
    )

    return has_errors, {
        "Details": details,
        "Schema": schema,
        "Diagnostics": diagnostics,
    }


# handles Create and Get responses for Table, View, Materialization
# also handles LoadDataResponse
def generic_response_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    details = table(_class="kda_table")
    schema_df = None
    if hasattr(obj, "table") and obj.HasField("table"):
        table_details, schema_df = shared.get_table_html_and_schema_df(obj.table)
        details.appendChild(html_table_row("table", table_details))
    elif hasattr(obj, "query"):
        query_details = shared.get_query_html(obj.query)
        details.appendChild(html_table_row("query", query_details))
    elif hasattr(obj, "view") and obj.HasField("view"):
        view_details, schema_df = shared.get_view_html_and_schema_df(obj.view)
        details.appendChild(html_table_row("view", view_details))
    elif hasattr(obj, "materialization") and obj.HasField("materialization"):
        mat_details, schema_df = shared.get_materialization_html_and_schema_df(
            obj.materialization
        )
        details.appendChild(html_table_row("materialization", mat_details))
    else:
        appendHtmlObjTableRowIfAttrExists(details, obj, "data_token_id")

    # pull of analysis
    diagnostics = None
    has_errors = False
    if hasattr(obj, "analysis"):
        (
            can_execute,
            has_errors,
            nested_details,
            diagnostics,
        ) = shared.get_analysis_and_diagnostics_tables(obj.analysis)
        details.appendChild(html_table_row("analysis", nested_details))

    appendChildIfNotNone(details, shared.get_request_details_table_row_if_exists(obj))

    schema = convert_df_to_domonic(schema_df) if schema_df is not None else None
    title_to_set_active = "Diagnostics" if has_errors else "Details"
    return str(
        tab_panel(
            [
                ("Details", details),
                ("Schema", schema),
                ("Diagnostics", diagnostics),
                ("Raw", shared.get_raw_html(obj)),
            ],
            title_to_set_active=title_to_set_active,
        )
    )


def query_resource_response_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    details = table(_class="kda_table")
    query_details = shared.get_query_html(obj.query)
    details.appendChild(html_table_row("query", query_details))

    appendChildIfNotNone(details, shared.get_request_details_table_row_if_exists(obj))

    return str(
        tab_panel(
            [
                ("Details", details),
                ("Raw", shared.get_raw_html(obj.query)),
            ],
            title_to_set_active="Details",
        )
    )


# handles Table, View, Materialization, and other generic objects
def generic_object_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    if get_classname(type(obj)) == "kaskada.kaskada.v1alpha.table_service_pb2.Table":
        details, schema_df = shared.get_table_html_and_schema_df(obj)
    elif get_classname(type(obj)) == "kaskada.kaskada.v1alpha.view_service_pb2.View":
        details, schema_df = shared.get_view_html_and_schema_df(obj)
    elif (
        get_classname(type(obj))
        == "kaskada.kaskada.v1alpha.materialization_service_pb2.Materialization"
    ):
        details, schema_df = shared.get_materialization_html_and_schema_df(obj)
    else:
        details, schema_df = shared.get_generic_object_html_and_schema_df(obj)

    schema = convert_df_to_domonic(schema_df) if schema_df is not None else None
    return str(
        tab_panel(
            [
                ("Details", details),
                ("Schema", schema),
                ("Raw", shared.get_raw_html(obj)),
            ]
        )
    )


# handles the Schema object
def schema_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    schema_df = get_schema_dataframe(obj)
    schema = convert_df_to_domonic(schema_df) if schema_df is not None else None

    return str(tab_panel([("Schema", schema), ("Raw", shared.get_raw_html(obj))]))


# handles the DataType object
def data_type_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    result_type, schema_df = shared.get_result_type_and_schema_df(obj)
    title_to_set_active = "Schema" if schema_df is not None else ""
    schema = convert_df_to_domonic(schema_df) if schema_df is not None else None

    return str(
        tab_panel(
            [
                ("Result Type", pre(result_type)),
                ("Schema", schema),
                ("Raw", shared.get_raw_html(obj)),
            ],
            title_to_set_active,
        )
    )


# handles Delete responses for Table, View, Materialization
def response_delete_html_formatter(del_resp):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    request_details = shared.get_request_details_table_row_if_exists(del_resp)

    del_resp_type = type(del_resp).__name__
    del_obj = del_resp_type.replace("Response", "")

    details = table(_class="kda_table")
    details.appendChild(html_obj_table_row(del_obj, "success"))
    details.appendChild(request_details)

    return str(
        tab_panel([("Details", details), ("Raw", pre(pprint.pformat(del_resp)))])
    )


# handles List responses for Tables, Views, Materializations
def response_list_html_formatter(list_resp):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    list_resp_type = type(list_resp).__name__
    list_key = list_resp_type.replace("Response", "").replace("List", "").lower()

    details = table(_class="kda_table")

    # after pulling the request_id, only the item list should remain
    props = get_properties(list_resp)
    if "request_details" in props:
        props.pop("request_details")
    if len(props) == 1:
        list_value = getattr(list_resp, list_key)
        list_props = props[list_key]
        list_type = type(list_value)
        nested_table = table(_class="kda_table")
        details.appendChild(html_table_row(list_key, nested_table))
        nested_table.appendChild(tr(th("index"), th("name")))
        if (
            get_classname(list_type)
            == "google._upb._message.RepeatedCompositeContainer"
        ):
            for i in range(len(list_value)):
                appendChildIfNotNone(
                    nested_table, html_obj_id_row(str(i), list_value[i], list_props[i])
                )
    else:  # when list is empty
        details.appendChild(html_table_row(list_key, Utils.escape("<empty>")))

    appendChildIfNotNone(
        details, shared.get_request_details_table_row_if_exists(list_resp)
    )

    return str(
        tab_panel([("Details", details), ("Raw", shared.get_raw_html(list_resp))])
    )


def response_list_queries_html_formatter(list_resp):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    list_resp_type = type(list_resp).__name__
    list_key = list_resp_type.replace("Response", "").replace("List", "").lower()

    details = table(_class="kda_table")

    # after pulling the request_id, only the item list should remain
    props = get_properties(list_resp)
    if "request_details" in props:
        props.pop("request_details")
    if len(props) == 1:
        list_value = getattr(list_resp, list_key)
        list_type = type(list_value)
        details.appendChild(tr(th("id"), th("query")))
        if (
            get_classname(list_type)
            == "google._upb._message.RepeatedCompositeContainer"
        ):
            for i in range(len(list_value)):
                details.appendChild(
                    tr(
                        td(str(i)),
                        td(
                            table(
                                tr(td("Query"), td(list_value[i].expression)),
                                tr(
                                    td("Created At"),
                                    td(list_value[i].create_time.ToJsonString()),
                                ),
                                tr(td("Query ID", td(list_value[i].query_id))),
                                tr(
                                    td(
                                        "Data Token",
                                        td(list_value[i].data_token_id.value),
                                    )
                                ),
                            )
                        ),
                    )
                )
    else:  # when list is empty
        details.appendChild(html_table_row(list_key, Utils.escape("<empty>")))

    appendChildIfNotNone(
        details, shared.get_request_details_table_row_if_exists(list_resp)
    )

    return str(
        tab_panel([("Details", details), ("Raw", shared.get_raw_html(list_resp))])
    )


def proto_list_html_formatter(list_resp):
    item_count = len(list_resp)
    if item_count == 0:
        return str(shared.get_raw_html(list_resp))

    output_custom_css_and_javascript_if_output_wrapped_in_iframe()
    details = table(_class="kda_table")

    # peek at the type of items in the list
    item_class = get_classname(type(list_resp[0]))

    if item_class == "kaskada.kaskada.v1alpha.fenl_diagnostics_pb2.FenlDiagnostic":
        for i in range(item_count):
            fenl_diag = list_resp[i]
            details.appendChild(html_obj_table_row(i, fenl_diag.formatted))
    else:
        details.appendChild(tr(th("index"), th("name")))
        for i in range(item_count):
            appendChildIfNotNone(
                details, html_obj_id_row(i, list_resp[i], get_properties(list_resp[i]))
            )

    return str(
        tab_panel([("Details", details), ("Raw", shared.get_raw_html(list_resp))])
    )


def slice_request_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()
    return str(
        tab_panel(
            [
                ("Details", shared.get_slice_request_html(obj)),
                ("Raw", shared.get_raw_html(obj)),
            ]
        )
    )


def query_metrics_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()
    return str(
        tab_panel(
            [
                ("Details", shared.get_metrics_html(obj)),
                ("Raw", shared.get_raw_html(obj)),
            ]
        )
    )


def query_response_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    has_errors, content = get_query_response_content(obj)
    title_to_set_active = "Diagnostics" if has_errors else "Details"
    return str(
        tab_panel(
            [
                ("Details", content["Details"]),
                ("Schema", content["Schema"]),
                ("Diagnostics", content["Diagnostics"]),
                ("Raw", shared.get_raw_html(obj)),
            ],
            title_to_set_active=title_to_set_active,
        )
    )


def query_v2_response_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    has_errors, content = get_query_response_content(obj)
    title_to_set_active = "Diagnostics" if has_errors else "Details"
    return str(
        tab_panel(
            [
                ("Details", content["Details"]),
                ("Schema", content["Schema"]),
                ("Diagnostics", content["Diagnostics"]),
                ("Raw", shared.get_raw_html(obj)),
            ],
            title_to_set_active=title_to_set_active,
        )
    )


def fenlmagic_query_result_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    has_errors, content = get_query_response_content(obj.query_response)
    details_table = content["Details"]
    details_table.appendChild(html_obj_table_row("query", obj.query))

    raw = {
        "query": obj.query,
        "query_response": obj.query_response,
    }

    dataframe = None
    if obj.dataframe is not None:
        buffer = io.StringIO()
        obj.dataframe.info(buf=buffer, verbose=False)
        raw["dataframe"] = buffer.getvalue().replace(
            "<class 'pandas.core.frame.DataFrame'>\n", ""
        )
        dataframe = convert_df_to_domonic(obj.dataframe, 10, True)

    title_to_set_active = "Details"
    if has_errors:
        title_to_set_active = "Diagnostics"
    elif dataframe is not None:
        title_to_set_active = "Dataframe"

    return str(
        tab_panel(
            [
                ("Dataframe", dataframe),
                ("Details", content["Details"]),
                ("Schema", content["Schema"]),
                ("Diagnostics", content["Diagnostics"]),
                ("Raw", shared.get_raw_html(raw)),
            ],
            title_to_set_active=title_to_set_active,
        )
    )


def entity_filter_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    details = table(_class="kda_table")
    filter_type = type(obj).__name__
    if filter_type == "EntityPercentFilter":
        details.appendChild(html_obj_table_row("percent", obj.percent))

    return str(tab_panel([("Details", details), ("Raw", shared.get_raw_html(obj))]))


def analysis_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    (
        can_execute,
        has_errors,
        details,
        diagnostics,
    ) = shared.get_analysis_and_diagnostics_tables(obj)
    title_to_set_active = "Diagnostics" if has_errors else "Details"
    return str(
        tab_panel(
            [
                ("Details", details),
                ("Diagnostics", diagnostics),
                ("Raw", shared.get_raw_html(obj)),
            ],
            title_to_set_active=title_to_set_active,
        )
    )


def fenl_diagnostics_html_formatter(obj):
    output_custom_css_and_javascript_if_output_wrapped_in_iframe()

    diagnostics, has_errors = shared.get_fenl_diagnostics_html_and_has_errors(obj)
    details = table(html_table_row("fenl_diagnostics", diagnostics))
    return str(tab_panel([("Details", details), ("Raw", shared.get_raw_html(obj))]))


def convert_df_to_domonic(df, max_rows=None, show_dimensions=False):
    parser = html5lib.HTMLParser(tree=getTreeBuilder())
    return parser.parse(
        df.to_html(max_rows=max_rows, notebook=True, show_dimensions=show_dimensions)
    )


def tab_panel(content_list, title_to_set_active=""):
    """
    Creates a tab-panel for the passed content list.

    Args:
        content_list (list of tuple of (str, Any)): A list of tuples, where the the first value
        in the tuple is the tab title, and the second is the tab contents.

        title_to_set_active str: The name of the tab title to set active when the panel loads. If
        unset, the first tab will be set active.

    Returns:
        domonic.html.div: A div html element wrapping the tabs and content.  Pass this value to
        str() to get the string html output.
    """
    if len(content_list) == 0:
        return None

    tab_links = div(_class="kda_tab")
    root_div = div(tab_links)

    for titleContent in content_list:
        title = titleContent[0]
        content = titleContent[1]
        if content is None:
            continue
        if title_to_set_active == "":
            title_to_set_active = title
        lower_title = title.lower()

        tab_button_class = (
            "kda_tablinks kda_active"
            if title_to_set_active == title
            else "kda_tablinks"
        )
        tab_links.appendChild(
            button(
                title,
                _class=tab_button_class,
                _onclick=f"openTab(event, '{lower_title}')",
            )
        )

        scroll_div = div(_class="kda_scroll_container").html(content)
        content_div = div(_class=f"{lower_title} kda_tabcontent").html(scroll_div)
        content_div.style.display = "block" if title_to_set_active == title else "none"
        root_div.appendChild(content_div)

    return root_div


def output_custom_css_and_javascript():
    """
    Outputs our custom css and javascript to the current cell
    """
    import IPython

    css = pkg_resources.resource_string(__name__, "formatters.css").decode("utf-8")
    js = pkg_resources.resource_string(__name__, "formatters.js").decode("utf-8")
    IPython.core.display.display(IPython.core.display.HTML(str(style(css))))
    IPython.core.display.display(
        IPython.core.display.HTML(str(script(js, _type="text/javascript")))
    )


def cell_output_is_wrapped_in_iframe():
    """
    Based on the environment that the code is running inside of, the cell output may be
    automatically wrapped in an iFrame.
    For example, in google colab: "the output of each cell is hosted in a separate iframe
    sandbox with limited access to the global notebook environment"
    In enviroments like these, we need to include our custom css & javascript in every output.

    Returns:
        bool: True if the environment will automatically wrap the cell output in an iFrame, otherwise False.
    """
    from IPython import get_ipython

    if "google.colab" in str(get_ipython()):
        return True
    else:
        return False


def output_custom_css_and_javascript_if_output_wrapped_in_iframe():
    """
    Outputs our custom css and javascript to the cell output if the output for the cell
    will be wrapped in an iFrame.  (i.e. in google colab)
    """
    if cell_output_is_wrapped_in_iframe():
        output_custom_css_and_javascript()


def try_init():
    try:
        from IPython import get_ipython

        # the following command will throw an exception in non-iPython
        # environments
        html_formatter = get_ipython().display_formatter.formatters["text/html"]
        # dynamically assign formatters to kaskada protobuf types
        mods = sys.modules.copy()
        for key in mods:
            if key.endswith("_grpc"):
                continue
            if key.startswith("kaskada.kaskada"):
                for cls in inspect.getmembers(mods[key], inspect.isclass):
                    classname = get_classname(cls[1])
                    if (
                        classname
                        == "kaskada.kaskada.v1alpha.query_service_pb2.CreateQueryResponse"
                    ):
                        html_formatter.for_type(
                            classname, query_v2_response_html_formatter
                        )
                    elif classname == "kaskada.kaskada.v1alpha.schema_pb2.Schema":
                        html_formatter.for_type(classname, schema_html_formatter)
                    elif classname == "kaskada.kaskada.v1alpha.schema_pb2.DataType":
                        html_formatter.for_type(classname, data_type_html_formatter)
                    elif classname == "kaskada.kaskada.v1alpha.slice_pb2.SliceRequest":
                        html_formatter.for_type(classname, slice_request_html_formatter)
                    elif (
                        classname
                        == "kaskada.kaskada.v1alpha.fenl_diagnostics_pb2.FenlDiagnostics"
                    ):
                        html_formatter.for_type(
                            classname, fenl_diagnostics_html_formatter
                        )
                    elif classname == "kaskada.kaskada.v1alpha.shared_pb2.Analysis":
                        html_formatter.for_type(classname, analysis_html_formatter)
                    elif "Delete" in classname and "Response" in classname:
                        html_formatter.for_type(
                            classname, response_delete_html_formatter
                        )  # generic formatter for Delete responses
                    elif "ListQueriesResponse" in classname:
                        html_formatter.for_type(
                            classname, response_list_queries_html_formatter
                        )
                    elif "List" in classname and "Response" in classname:
                        html_formatter.for_type(
                            classname, response_list_html_formatter
                        )  # generic formatter for List responses
                    elif "Response" in classname:
                        html_formatter.for_type(
                            classname, generic_response_html_formatter
                        )  # generic formatter for other responses
                    else:
                        html_formatter.for_type(
                            classname, generic_object_html_formatter
                        )  # generic formatter for all other objects

        # the following types don't normally exist when the library first loads
        html_formatter.for_type(
            "kaskada.kaskada.v1alpha.compute_service_pb2.Metrics",
            query_metrics_html_formatter,
        )
        html_formatter.for_type(
            "kaskada.materialization.MaterializationView", generic_object_html_formatter
        )
        html_formatter.for_type(
            "kaskada.materialization.RedisAIDestination", generic_object_html_formatter
        )
        html_formatter.for_type(
            "kaskada.kaskada.v1alpha.materialization_service_pb2.RedisAI",
            generic_object_html_formatter,
        )
        html_formatter.for_type(
            "kaskada.kaskada.v1alpha.materialization_service_pb2.Destination",
            generic_object_html_formatter,
        )
        html_formatter.for_type(
            "kaskada.compute.EntityPercentFilter", entity_filter_html_formatter
        )
        html_formatter.for_type(
            "fenlmagic.QueryResult", fenlmagic_query_result_html_formatter
        )
        html_formatter.for_type(
            "kaskada.query.QueryResource", query_resource_response_html_formatter
        )

        # additional non-kaskada types we want to assign formatters to
        html_formatter.for_type(
            "google.protobuf.pyext._message.RepeatedCompositeContainer",
            proto_list_html_formatter,
        )

        if not cell_output_is_wrapped_in_iframe():
            # load our custom css into the page
            output_custom_css_and_javascript()

    except Exception as e:
        _LOGGER.debug("Init exception: {}".format(e))



import logging
import sys
from abc import ABC, abstractmethod
from enum import Enum
from typing import Any, Dict, List, Optional

import grpc

import kaskada.kaskada.v1alpha.common_pb2 as common_pb
import kaskada.kaskada.v1alpha.materialization_service_pb2 as material_pb
from kaskada.client import Client, SliceFilter, get_client
from kaskada.utils import handleException, handleGrpcError

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logger = logging.getLogger(__name__)


class Destination(ABC):
    @abstractmethod
    def to_request(self) -> Dict[str, Any]:
        pass


class RedisDestination(Destination):
    def __init__(
        self,
        host_name: str,
        port: int,
        use_tls: bool,
        database_number: int,
        password: str,
        tls_cert: str,
        tls_key: str,
        tls_ca_cert: str,
        insecure_skip_verify: bool,
    ) -> None:
        super().__init__()
        self._host_name = host_name
        self._port = port
        self._use_tls = use_tls
        self._database_number = database_number
        self._password = password
        self._tls_cert = tls_cert
        self._tls_key = tls_key
        self._tls_ca_cert = tls_ca_cert
        self._insecure_skip_verify = insecure_skip_verify

    def to_request(self) -> Dict[str, Any]:
        return {
            "host_name": self._host_name,
            "port": self._port,
            "use_tls": self._use_tls,
            "database_number": self._database_number,
            "password": self._password,
            "tls_cert": self._tls_cert,
            "tls_key": self._tls_key,
            "tls_ca_cert": self._tls_ca_cert,
            "insecure_skip_verify": self._insecure_skip_verify,
        }


class FileFormat(Enum):
    FILE_FORMAT_UNSPECIFIED = 0
    FILE_FORMAT_PARQUET = 1
    FILE_FORMAT_CSV = 2


class ObjectStoreDestination(Destination):
    def __init__(self, file_format: FileFormat, output_prefix_uri: str):
        self._file_format = file_format
        self._output_prefix_uri = output_prefix_uri

    def to_request(self) -> Dict[str, Any]:
        return {
            "format": self._file_format.name,
            "output_prefix_uri": self._output_prefix_uri,
        }


class MaterializationView(object):
    def __init__(self, name: str, expression: str):
        """
        Kaskada Materialization View

        Args:
            name (str): The name of the view
            expression (str): The fenl expression to compute
        """
        self._name = name
        self._expression = expression


def create_materialization(
    name: str,
    query: str,
    destination: Destination,
    views: List[MaterializationView],
    slice_filter: SliceFilter = None,
    client: Client = None,
) -> material_pb.CreateMaterializationResponse:
    try:
        slice_request = None
        if slice_filter is not None:
            slice_request = common_pb.SliceRequest(**slice_filter.to_request())
        materialization = {
            "materialization_name": name,
            "query": query,
            "with_views": to_with_views(views),
            "slice": slice_request,
        }
        if isinstance(destination, ObjectStoreDestination):
            materialization["destination"] = {"object_store": destination.to_request()}
        elif isinstance(destination, RedisDestination):
            materialization["destination"] = {"redis": destination.to_request()}
        else:
            raise ValueError("invalid destination supplied")

        req = material_pb.CreateMaterializationRequest(
            **{"materialization": materialization}
        )
        logger.debug(f"Create Materialization Request: {req}")
        client = get_client(client)
        return client.materialization_stub.CreateMaterialization(
            req, metadata=client.get_metadata()
        )
    except grpc.RpcError as e:
        handleGrpcError(e)
    except Exception as e:
        handleException(e)


def delete_materialization(
    name: str, client: Client = None
) -> material_pb.DeleteMaterializationResponse:
    try:
        client = get_client(client)
        req = material_pb.DeleteMaterializationRequest(materialization_name=name)
        logger.debug(f"Delete Materialization Request: {req}")
        return client.materialization_stub.DeleteMaterialization(
            req, metadata=client.get_metadata()
        )
    except grpc.RpcError as e:
        handleGrpcError(e)
    except Exception as e:
        handleException(e)


def get_materialization(
    name: str, client: Client = None
) -> material_pb.GetMaterializationResponse:
    try:
        client = get_client(client)
        req = material_pb.GetMaterializationRequest(materialization_name=name)
        logger.debug(f"Get Materialization Request: {req}")
        return client.materialization_stub.GetMaterialization(
            req, metadata=client.get_metadata()
        )
    except grpc.RpcError as e:
        handleGrpcError(e)
    except Exception as e:
        handleException(e)


def list_materializations(
    search: Optional[str] = None, client: Client = None
) -> material_pb.ListMaterializationsResponse:
    try:
        client = get_client(client)
        req = material_pb.ListMaterializationsRequest(
            search=search,
        )
        logger.debug(f"List Materialization Request: {req}")
        return client.materialization_stub.ListMaterializations(
            req, metadata=client.get_metadata()
        )
    except grpc.RpcError as e:
        handleGrpcError(e)
    except Exception as e:
        handleException(e)


def to_with_views(views: List[MaterializationView]) -> List[material_pb.WithView]:
    with_views = []
    for v in views:
        with_views.append(material_pb.WithView(name=v._name, expression=v._expression))
    return with_views



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/query_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2
from kaskada.kaskada.v1alpha import view_service_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_view__service__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+kaskada/kaskada/v1alpha/query_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a$kaskada/kaskada/v1alpha/common.proto\x1a.kaskada/kaskada/v1alpha/fenl_diagnostics.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\x1a*kaskada/kaskada/v1alpha/view_service.proto\x1a\x17validate/validate.proto\"\xec\x08\n\x05Query\x12\x1e\n\x08query_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07queryId\x12\'\n\nexpression\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\x12=\n\x08\x61s_files\x18\x65 \x01(\x0b\x32 .kaskada.kaskada.v1alpha.AsFilesH\x00R\x07\x61sFiles\x12\x44\n\tredis_a_i\x18\x66 \x01(\x0b\x32&.kaskada.kaskada.v1alpha.Query.RedisAIH\x00R\x07redisAI\x12@\n\rdata_token_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x61taTokenId\x12\x38\n\x05views\x18\x04 \x03(\x0b\x32\x1d.kaskada.kaskada.v1alpha.ViewB\x03\xe0\x41\x03R\x05views\x12V\n\x0fresult_behavior\x18\x05 \x01(\x0e\x32-.kaskada.kaskada.v1alpha.Query.ResultBehaviorR\x0eresultBehavior\x12=\n\x06limits\x18\x06 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.Query.LimitsR\x06limits\x12;\n\x05slice\x18\x07 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.SliceRequestR\x05slice\x12H\n\x12\x63hanged_since_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x63hangedSinceTime\x12\x46\n\x11\x66inal_result_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inalResultTime\x12@\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x1a+\n\x06Limits\x12!\n\x0cpreview_rows\x18\x01 \x01(\x03R\x0bpreviewRows\x1a)\n\x11RedisBulkResponse\x12\x14\n\x05shape\x18\x01 \x03(\x05R\x05shape\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04port\"\xa0\x01\n\x0eResultBehavior\x12\x1f\n\x1bRESULT_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x1f\n\x1bRESULT_BEHAVIOR_ALL_RESULTS\x10\x01\x12!\n\x1dRESULT_BEHAVIOR_FINAL_RESULTS\x10\x02\x12)\n%RESULT_BEHAVIOR_FINAL_RESULTS_AT_TIME\x10\x03\x42\x12\n\x0bresponse_as\x12\x03\xf8\x42\x01\"\xac\x01\n\x0cQueryOptions\x12\x17\n\x07\x64ry_run\x18\x01 \x01(\x08R\x06\x64ryRun\x12\x33\n\x15\x65xperimental_features\x18\x02 \x01(\x08R\x14\x65xperimentalFeatures\x12%\n\x0estream_metrics\x18\x03 \x01(\x08R\rstreamMetrics\x12\'\n\x0fpresign_results\x18\x04 \x01(\x08R\x0epresignResults\"\x96\x01\n\x12\x43reateQueryRequest\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v1alpha.QueryR\x05query\x12J\n\rquery_options\x18\x02 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.QueryOptionsR\x0cqueryOptions\"\xec\n\n\x13\x43reateQueryResponse\x12H\n\x05state\x18\x01 \x01(\x0e\x32\x32.kaskada.kaskada.v1alpha.CreateQueryResponse.StateR\x05state\x12K\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x33.kaskada.kaskada.v1alpha.CreateQueryResponse.ConfigR\x06\x63onfig\x12Q\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x35.kaskada.kaskada.v1alpha.CreateQueryResponse.AnalysisR\x08\x61nalysis\x12S\n\x10\x66\x65nl_diagnostics\x18\x04 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12N\n\x07metrics\x18\x05 \x01(\x0b\x32\x34.kaskada.kaskada.v1alpha.CreateQueryResponse.MetricsR\x07metrics\x12P\n\x0frequest_details\x18\x06 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\x12\x19\n\x08query_id\x18\x07 \x01(\tR\x07queryId\x12I\n\x0c\x66ile_results\x18\x65 \x01(\x0b\x32$.kaskada.kaskada.v1alpha.FileResultsH\x00R\x0b\x66ileResults\x12R\n\tredis_a_i\x18\x66 \x01(\x0b\x32\x34.kaskada.kaskada.v1alpha.CreateQueryResponse.RedisAIH\x00R\x07redisAI\x1a\x64\n\x08\x41nalysis\x12\x1f\n\x0b\x63\x61n_execute\x18\x01 \x01(\x08R\ncanExecute\x12\x37\n\x06schema\x18\x02 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaR\x06schema\x1ax\n\x06\x43onfig\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12J\n\rslice_request\x18\x02 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.SliceRequestR\x0csliceRequest\x1a\xbe\x02\n\x07Metrics\x12@\n\x0etime_preparing\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\rtimePreparing\x12@\n\x0etime_computing\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\rtimeComputing\x12!\n\x0coutput_files\x18\x03 \x01(\x03R\x0boutputFiles\x12(\n\x10total_input_rows\x18\x04 \x01(\x03R\x0etotalInputRows\x12\x30\n\x14processed_input_rows\x18\x05 \x01(\x03R\x12processedInputRows\x12\x30\n\x14produced_output_rows\x18\x06 \x01(\x03R\x12producedOutputRows\x1a\t\n\x07RedisAI\"\x82\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_ANALYSIS\x10\x01\x12\x13\n\x0fSTATE_PREPARING\x10\x02\x12\x13\n\x0fSTATE_COMPUTING\x10\x03\x12\x11\n\rSTATE_SUCCESS\x10\x04\x12\x11\n\rSTATE_FAILURE\x10\x05\x42\t\n\x07results\"5\n\x0fGetQueryRequest\x12\"\n\x08query_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07queryId\"M\n\x10GetQueryResponse\x12\x39\n\x05query\x18\x01 \x01(\x0b\x32\x1e.kaskada.kaskada.v1alpha.QueryB\x03\xe0\x41\x03R\x05query\"t\n\x12ListQueriesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc9\x01\n\x13ListQueriesResponse\x12\x38\n\x07queries\x18\x01 \x03(\x0b\x32\x1e.kaskada.kaskada.v1alpha.QueryR\x07queries\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12P\n\x0frequest_details\x18\x03 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails2\xaa\x03\n\x0cQueryService\x12\x8b\x01\n\x0b\x43reateQuery\x12+.kaskada.kaskada.v1alpha.CreateQueryRequest\x1a,.kaskada.kaskada.v1alpha.CreateQueryResponse\"\x1f\x82\xd3\xe4\x93\x02\x19:\x05query\"\x10/v1alpha/queries0\x01\x12\x86\x01\n\x08GetQuery\x12(.kaskada.kaskada.v1alpha.GetQueryRequest\x1a).kaskada.kaskada.v1alpha.GetQueryResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1alpha/queries/{query_id=*}\x12\x82\x01\n\x0bListQueries\x12+.kaskada.kaskada.v1alpha.ListQueriesRequest\x1a,.kaskada.kaskada.v1alpha.ListQueriesResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1alpha/queriesB\x81\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x11QueryServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_QUERY = DESCRIPTOR.message_types_by_name['Query']
_QUERY_LIMITS = _QUERY.nested_types_by_name['Limits']
_QUERY_REDISBULKRESPONSE = _QUERY.nested_types_by_name['RedisBulkResponse']
_QUERY_REDISAI = _QUERY.nested_types_by_name['RedisAI']
_QUERYOPTIONS = DESCRIPTOR.message_types_by_name['QueryOptions']
_CREATEQUERYREQUEST = DESCRIPTOR.message_types_by_name['CreateQueryRequest']
_CREATEQUERYRESPONSE = DESCRIPTOR.message_types_by_name['CreateQueryResponse']
_CREATEQUERYRESPONSE_ANALYSIS = _CREATEQUERYRESPONSE.nested_types_by_name['Analysis']
_CREATEQUERYRESPONSE_CONFIG = _CREATEQUERYRESPONSE.nested_types_by_name['Config']
_CREATEQUERYRESPONSE_METRICS = _CREATEQUERYRESPONSE.nested_types_by_name['Metrics']
_CREATEQUERYRESPONSE_REDISAI = _CREATEQUERYRESPONSE.nested_types_by_name['RedisAI']
_GETQUERYREQUEST = DESCRIPTOR.message_types_by_name['GetQueryRequest']
_GETQUERYRESPONSE = DESCRIPTOR.message_types_by_name['GetQueryResponse']
_LISTQUERIESREQUEST = DESCRIPTOR.message_types_by_name['ListQueriesRequest']
_LISTQUERIESRESPONSE = DESCRIPTOR.message_types_by_name['ListQueriesResponse']
_QUERY_RESULTBEHAVIOR = _QUERY.enum_types_by_name['ResultBehavior']
_CREATEQUERYRESPONSE_STATE = _CREATEQUERYRESPONSE.enum_types_by_name['State']
Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {

  'Limits' : _reflection.GeneratedProtocolMessageType('Limits', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_LIMITS,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Query.Limits)
    })
  ,

  'RedisBulkResponse' : _reflection.GeneratedProtocolMessageType('RedisBulkResponse', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_REDISBULKRESPONSE,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Query.RedisBulkResponse)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _QUERY_REDISAI,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Query.RedisAI)
    })
  ,
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Query)
  })
_sym_db.RegisterMessage(Query)
_sym_db.RegisterMessage(Query.Limits)
_sym_db.RegisterMessage(Query.RedisBulkResponse)
_sym_db.RegisterMessage(Query.RedisAI)

QueryOptions = _reflection.GeneratedProtocolMessageType('QueryOptions', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOPTIONS,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.QueryOptions)
  })
_sym_db.RegisterMessage(QueryOptions)

CreateQueryRequest = _reflection.GeneratedProtocolMessageType('CreateQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEQUERYREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryRequest)
  })
_sym_db.RegisterMessage(CreateQueryRequest)

CreateQueryResponse = _reflection.GeneratedProtocolMessageType('CreateQueryResponse', (_message.Message,), {

  'Analysis' : _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
    'DESCRIPTOR' : _CREATEQUERYRESPONSE_ANALYSIS,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse.Analysis)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _CREATEQUERYRESPONSE_CONFIG,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse.Config)
    })
  ,

  'Metrics' : _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {
    'DESCRIPTOR' : _CREATEQUERYRESPONSE_METRICS,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse.Metrics)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _CREATEQUERYRESPONSE_REDISAI,
    '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse.RedisAI)
    })
  ,
  'DESCRIPTOR' : _CREATEQUERYRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateQueryResponse)
  })
_sym_db.RegisterMessage(CreateQueryResponse)
_sym_db.RegisterMessage(CreateQueryResponse.Analysis)
_sym_db.RegisterMessage(CreateQueryResponse.Config)
_sym_db.RegisterMessage(CreateQueryResponse.Metrics)
_sym_db.RegisterMessage(CreateQueryResponse.RedisAI)

GetQueryRequest = _reflection.GeneratedProtocolMessageType('GetQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetQueryRequest)
  })
_sym_db.RegisterMessage(GetQueryRequest)

GetQueryResponse = _reflection.GeneratedProtocolMessageType('GetQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetQueryResponse)
  })
_sym_db.RegisterMessage(GetQueryResponse)

ListQueriesRequest = _reflection.GeneratedProtocolMessageType('ListQueriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListQueriesRequest)
  })
_sym_db.RegisterMessage(ListQueriesRequest)

ListQueriesResponse = _reflection.GeneratedProtocolMessageType('ListQueriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTQUERIESRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.query_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListQueriesResponse)
  })
_sym_db.RegisterMessage(ListQueriesResponse)

_QUERYSERVICE = DESCRIPTOR.services_by_name['QueryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\021QueryServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _QUERY_REDISAI.fields_by_name['db']._options = None
  _QUERY_REDISAI.fields_by_name['db']._serialized_options = b'\372B\006\032\004\030\017(\000'
  _QUERY_REDISAI.fields_by_name['host']._options = None
  _QUERY_REDISAI.fields_by_name['host']._serialized_options = b'\372B\004r\002\020\001'
  _QUERY_REDISAI.fields_by_name['port']._options = None
  _QUERY_REDISAI.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _QUERY.oneofs_by_name['response_as']._options = None
  _QUERY.oneofs_by_name['response_as']._serialized_options = b'\370B\001'
  _QUERY.fields_by_name['query_id']._options = None
  _QUERY.fields_by_name['query_id']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['expression']._options = None
  _QUERY.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _QUERY.fields_by_name['views']._options = None
  _QUERY.fields_by_name['views']._serialized_options = b'\340A\003'
  _QUERY.fields_by_name['create_time']._options = None
  _QUERY.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _GETQUERYREQUEST.fields_by_name['query_id']._options = None
  _GETQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETQUERYRESPONSE.fields_by_name['query']._options = None
  _GETQUERYRESPONSE.fields_by_name['query']._serialized_options = b'\340A\003'
  _LISTQUERIESREQUEST.fields_by_name['page_size']._options = None
  _LISTQUERIESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _QUERYSERVICE.methods_by_name['CreateQuery']._options = None
  _QUERYSERVICE.methods_by_name['CreateQuery']._serialized_options = b'\202\323\344\223\002\031:\005query\"\020/v1alpha/queries'
  _QUERYSERVICE.methods_by_name['GetQuery']._options = None
  _QUERYSERVICE.methods_by_name['GetQuery']._serialized_options = b'\202\323\344\223\002\037\022\035/v1alpha/queries/{query_id=*}'
  _QUERYSERVICE.methods_by_name['ListQueries']._options = None
  _QUERYSERVICE.methods_by_name['ListQueries']._serialized_options = b'\202\323\344\223\002\022\022\020/v1alpha/queries'
  _QUERY._serialized_start=426
  _QUERY._serialized_end=1558
  _QUERY_LIMITS._serialized_start=1189
  _QUERY_LIMITS._serialized_end=1232
  _QUERY_REDISBULKRESPONSE._serialized_start=1234
  _QUERY_REDISBULKRESPONSE._serialized_end=1275
  _QUERY_REDISAI._serialized_start=1277
  _QUERY_REDISAI._serialized_end=1375
  _QUERY_RESULTBEHAVIOR._serialized_start=1378
  _QUERY_RESULTBEHAVIOR._serialized_end=1538
  _QUERYOPTIONS._serialized_start=1561
  _QUERYOPTIONS._serialized_end=1733
  _CREATEQUERYREQUEST._serialized_start=1736
  _CREATEQUERYREQUEST._serialized_end=1886
  _CREATEQUERYRESPONSE._serialized_start=1889
  _CREATEQUERYRESPONSE._serialized_end=3277
  _CREATEQUERYRESPONSE_ANALYSIS._serialized_start=2579
  _CREATEQUERYRESPONSE_ANALYSIS._serialized_end=2679
  _CREATEQUERYRESPONSE_CONFIG._serialized_start=2681
  _CREATEQUERYRESPONSE_CONFIG._serialized_end=2801
  _CREATEQUERYRESPONSE_METRICS._serialized_start=2804
  _CREATEQUERYRESPONSE_METRICS._serialized_end=3122
  _CREATEQUERYRESPONSE_REDISAI._serialized_start=1277
  _CREATEQUERYRESPONSE_REDISAI._serialized_end=1286
  _CREATEQUERYRESPONSE_STATE._serialized_start=3136
  _CREATEQUERYRESPONSE_STATE._serialized_end=3266
  _GETQUERYREQUEST._serialized_start=3279
  _GETQUERYREQUEST._serialized_end=3332
  _GETQUERYRESPONSE._serialized_start=3334
  _GETQUERYRESPONSE._serialized_end=3411
  _LISTQUERIESREQUEST._serialized_start=3413
  _LISTQUERIESREQUEST._serialized_end=3529
  _LISTQUERIESRESPONSE._serialized_start=3532
  _LISTQUERIESRESPONSE._serialized_end=3733
  _QUERYSERVICE._serialized_start=3736
  _QUERYSERVICE._serialized_end=4162
# @@protoc_insertion_point(module_scope)
